"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._852 import (
        ActiveProfileRangeCalculationSource,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._853 import (
        AxialShaverRedressing,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._854 import (
        ConventionalShavingDynamics,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._855 import (
        ConventionalShavingDynamicsCalculationForDesignedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._856 import (
        ConventionalShavingDynamicsCalculationForHobbedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._857 import (
        ConventionalShavingDynamicsViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._858 import (
        PlungeShaverDynamics,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._859 import (
        PlungeShaverDynamicSettings,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._860 import (
        PlungeShaverRedressing,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._861 import (
        PlungeShavingDynamicsCalculationForDesignedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._862 import (
        PlungeShavingDynamicsCalculationForHobbedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._863 import (
        PlungeShavingDynamicsViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._864 import (
        RedressingSettings,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._865 import (
        RollAngleRangeRelativeToAccuracy,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._866 import (
        RollAngleReportObject,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._867 import (
        ShaverRedressing,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._868 import (
        ShavingDynamics,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._869 import (
        ShavingDynamicsCalculation,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._870 import (
        ShavingDynamicsCalculationForDesignedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._871 import (
        ShavingDynamicsCalculationForHobbedGears,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._872 import (
        ShavingDynamicsConfiguration,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._873 import (
        ShavingDynamicsViewModel,
    )
    from mastapy._private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._874 import (
        ShavingDynamicsViewModelBase,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._852": [
            "ActiveProfileRangeCalculationSource"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._853": [
            "AxialShaverRedressing"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._854": [
            "ConventionalShavingDynamics"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._855": [
            "ConventionalShavingDynamicsCalculationForDesignedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._856": [
            "ConventionalShavingDynamicsCalculationForHobbedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._857": [
            "ConventionalShavingDynamicsViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._858": [
            "PlungeShaverDynamics"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._859": [
            "PlungeShaverDynamicSettings"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._860": [
            "PlungeShaverRedressing"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._861": [
            "PlungeShavingDynamicsCalculationForDesignedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._862": [
            "PlungeShavingDynamicsCalculationForHobbedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._863": [
            "PlungeShavingDynamicsViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._864": [
            "RedressingSettings"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._865": [
            "RollAngleRangeRelativeToAccuracy"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._866": [
            "RollAngleReportObject"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._867": [
            "ShaverRedressing"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._868": [
            "ShavingDynamics"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._869": [
            "ShavingDynamicsCalculation"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._870": [
            "ShavingDynamicsCalculationForDesignedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._871": [
            "ShavingDynamicsCalculationForHobbedGears"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._872": [
            "ShavingDynamicsConfiguration"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._873": [
            "ShavingDynamicsViewModel"
        ],
        "_private.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics._874": [
            "ShavingDynamicsViewModelBase"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "ActiveProfileRangeCalculationSource",
    "AxialShaverRedressing",
    "ConventionalShavingDynamics",
    "ConventionalShavingDynamicsCalculationForDesignedGears",
    "ConventionalShavingDynamicsCalculationForHobbedGears",
    "ConventionalShavingDynamicsViewModel",
    "PlungeShaverDynamics",
    "PlungeShaverDynamicSettings",
    "PlungeShaverRedressing",
    "PlungeShavingDynamicsCalculationForDesignedGears",
    "PlungeShavingDynamicsCalculationForHobbedGears",
    "PlungeShavingDynamicsViewModel",
    "RedressingSettings",
    "RollAngleRangeRelativeToAccuracy",
    "RollAngleReportObject",
    "ShaverRedressing",
    "ShavingDynamics",
    "ShavingDynamicsCalculation",
    "ShavingDynamicsCalculationForDesignedGears",
    "ShavingDynamicsCalculationForHobbedGears",
    "ShavingDynamicsConfiguration",
    "ShavingDynamicsViewModel",
    "ShavingDynamicsViewModelBase",
)
